@@ -5,8 +5,10 @@ import (
 	"fmt"
 
 	"github.com/goreleaser/goreleaser/internal/middleware"
+	"github.com/goreleaser/goreleaser/internal/pipe/discord"
 	"github.com/goreleaser/goreleaser/internal/pipe/reddit"
 	"github.com/goreleaser/goreleaser/internal/pipe/slack"
+	"github.com/goreleaser/goreleaser/internal/pipe/teams"
 	"github.com/goreleaser/goreleaser/internal/pipe/twitter"
 	"github.com/goreleaser/goreleaser/pkg/context"
 )
@@ -27,9 +29,12 @@ type Announcer interface {
 
 // nolint: gochecknoglobals
 var announcers = []Announcer{
-	twitter.Pipe{}, // announce to twitter
-	reddit.Pipe{},  // announce to twitter
-	slack.Pipe{},   // announce to slack
+	// XXX: keep asc sorting
+	discord.Pipe{},
+	reddit.Pipe{},
+	slack.Pipe{},
+	teams.Pipe{},
+	twitter.Pipe{},
 }
 
 // Run the pipe.
