@@ -33,21 +33,21 @@ func TestDockerSignDisabled(t *testing.T) {
 	ctx.Config.DockerSigns = []config.Sign{
 		{Artifacts: "none"},
 	}
-	err := DockerPipe{}.Run(ctx)
+	err := DockerPipe{}.Publish(ctx)
 	require.EqualError(t, err, "artifact signing is disabled")
 }
 
 func TestDockerSignSkipped(t *testing.T) {
 	ctx := context.New(config.Project{})
 	ctx.SkipSign = true
-	err := DockerPipe{}.Run(ctx)
+	err := DockerPipe{}.Publish(ctx)
 	require.EqualError(t, err, "artifact signing is disabled")
 }
 
 func TestDockerSignSkipPublish(t *testing.T) {
 	ctx := context.New(config.Project{})
 	ctx.SkipPublish = true
-	err := DockerPipe{}.Run(ctx)
+	err := DockerPipe{}.Publish(ctx)
 	require.EqualError(t, err, "artifact signing is disabled")
 }
 
@@ -56,7 +56,7 @@ func TestDockerSignInvalidArtifacts(t *testing.T) {
 	ctx.Config.DockerSigns = []config.Sign{
 		{Artifacts: "foo"},
 	}
-	err := DockerPipe{}.Run(ctx)
+	err := DockerPipe{}.Publish(ctx)
 	require.EqualError(t, err, "invalid list of artifacts to sign: foo")
 }
 
@@ -178,7 +178,7 @@ func TestDockerSignArtifacts(t *testing.T) {
 			})
 
 			require.NoError(t, DockerPipe{}.Default(ctx))
-			require.NoError(t, DockerPipe{}.Run(ctx))
+			require.NoError(t, DockerPipe{}.Publish(ctx))
 			var sigs []string
 			for _, sig := range ctx.Artifacts.Filter(artifact.ByType(artifact.Signature)).List() {
 				sigs = append(sigs, sig.Name)
