@@ -201,7 +201,7 @@ type Build struct {
 	Binary          string         `yaml:",omitempty"`
 	Hooks           HookConfig     `yaml:",omitempty"`
 	Env             []string       `yaml:",omitempty"`
-	Lang            string         `yaml:",omitempty"`
+	Builder         string         `yaml:",omitempty"`
 	Asmflags        StringArray    `yaml:",omitempty"`
 	Gcflags         StringArray    `yaml:",omitempty"`
 	ModTimestamp    string         `yaml:"mod_timestamp,omitempty"`
@@ -694,6 +694,8 @@ type Announce struct {
 	Twitter Twitter `yaml:"twitter,omitempty"`
 	Reddit  Reddit  `yaml:"reddit,omitempty"`
 	Slack   Slack   `yaml:"slack,omitempty"`
+	Discord Discord `yaml:"discord,omitempty"`
+	Teams   Teams   `yaml:"teams,omitempty"`
 }
 
 type Twitter struct {
@@ -719,6 +721,22 @@ type Slack struct {
 	IconURL         string `yaml:"icon_url,omitempty"`
 }
 
+type Discord struct {
+	Enabled         bool   `yaml:"enabled,omitempty"`
+	MessageTemplate string `yaml:"message_template,omitempty"`
+	Author          string `yaml:"author,omitempty"`
+	Color           string `yaml:"color,omitempty"`
+	IconURL         string `yaml:"icon_url,omitempty"`
+}
+
+type Teams struct {
+	Enabled         bool   `yaml:"enabled,omitempty"`
+	TitleTemplate   string `yaml:"title_template,omitempty"`
+	MessageTemplate string `yaml:"message_template,omitempty"`
+	Color           string `yaml:"color,omitempty"`
+	IconURL         string `yaml:"icon_url,omitempty"`
+}
+
 // Load config file.
 func Load(file string) (config Project, err error) {
 	f, err := os.Open(file) // #nosec
